% habitat Jobs
%
%

# habitat Jobs

*relatively* independent collections of stuff that needs to be
done:

-   Message Server Python
    -   Master
    -   Spooler
    -   Dummy (depends on/shares spooler code)

-   Browser-side HTML5, CSS, JS, jQuery
    -   UI abstraction jQuery UI
    -   Map abstraction Google Maps, OpenStreetMaps
    -   Predictor, Archive, Mission Control & Admin clients CouchDB

-   Parser Python
-   Archive Python, CouchDB
    -   Master
    -   Chase-car replication capabilities

-   Points game Python
-   Message repairer Python

habitat plan – Copyright Daniel Richman and Adam Greig 2010
This work is licensed under a Creative Commons
Attribution-NonCommerical-ShareAlike 2.0 UK:England & Wales License

[http://creativecommons.org/licenses/by-nc-sa/2.0/uk/](http://creativecommons.org/licenses/by-nc-sa/2.0/uk/)



